==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorppur/asset/service/impl/AssetAmortizeBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.asset.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.proequipmentcorppur.acceptance.vo.PurchaseAcceptanceVO;
import com.ejianc.business.proequipmentcorppur.asset.bean.*;
import com.ejianc.business.proequipmentcorppur.asset.service.*;
import com.ejianc.business.proequipmentcorppur.utils.DateUtil;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.core.util.DateFormater;
import org.apache.commons.collections.CollectionUtils;
import com.ejianc.business.procost.api.ICostDetailApi;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service("assetAmortize")
public class AssetAmortizeBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;

    @Autowired
    private ICostDetailApi costDetailApi;

    @Autowired
    private IAssetAmortizeService assetAmortizeService;


    @Autowired
    private IAssetService assetService;

    @Autowired
    private IAssetAllotOutDetailService assetAllotOutDetailService;


    @Autowired
    private IAssetScrapDetailService assetScrapDetailService;


    @Autowired
    private IHandleDetailService handleDetailService;


    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        // 审核完成回写资产卡片摊销金额
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            Date amortizeDate = assetAmortizeEntity.getAmortizeDate();
            Long projectId = assetAmortizeEntity.getProjectId();
            for (AssetAmortizeDetailEntity entity : detailList) {
                Long assetId = entity.getAssetId();
                BigDecimal amortizeMnyTax = entity.getAmortizeMnyTax();
                BigDecimal amortizeMny = entity.getAmortizeMny();


                AssetEntity assetEntity = assetService.selectById(assetId);
                BigDecimal sumAmortizeTaxMny = ComputeUtil.safeAdd(amortizeMnyTax, assetEntity.getLastAmortizeTaxMny());
                BigDecimal sumAmortizeMny = ComputeUtil.safeAdd(amortizeMny, assetEntity.getLastAmortizeMny());
                BigDecimal netWorthTax = ComputeUtil.safeSub(assetEntity.getOriginalValueTax(), sumAmortizeTaxMny);
                BigDecimal netWorth = ComputeUtil.safeSub(assetEntity.getOriginalValue(), sumAmortizeMny);

                LambdaUpdateWrapper<AssetEntity> wrapper = new LambdaUpdateWrapper<>();
                wrapper.eq(AssetEntity::getId, assetId);
                wrapper.eq(AssetEntity::getProjectId, projectId);
                wrapper.set(AssetEntity::getLastAmortizeDate, amortizeDate);
                wrapper.set(AssetEntity::getLastAmortizeTaxMny, sumAmortizeTaxMny);
                wrapper.set(AssetEntity::getLastAmortizeMny, sumAmortizeMny);
                wrapper.set(AssetEntity::getNetWorthTax, netWorthTax);
                wrapper.set(AssetEntity::getNetWorth, netWorth);
                assetService.update(wrapper);
            }
            logger.info("推送成本---");
            AssetAmortizeEntity assetAmortizeEntity1 = assetAmortizeService.selectById(billId);
            assetAmortizeService.costPush(assetAmortizeEntity1);
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        // 参数是单据类型编码字符串 根据需求是否打开下面代码
        /**CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
         if(!resp.isSuccess()){
         return CommonResponse.error("无法撤回！"+resp.getMsg());
         }*/
        //TODO 弃审 校验是否被成本归集引用 引用则不能
        CommonResponse<String> checkCommonResponse = billTypeApi.checkQuote(billTypeCode, billId);
        boolean success = checkCommonResponse.isSuccess();
        if (!success){
            return CommonResponse.error("已经被归集单使用,不能弃审和撤回");
        }
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        Date createTime = assetAmortizeEntity.getCreateTime();
        if (CollectionUtils.isNotEmpty(detailList)) {
            List<Long> assetIds = detailList.stream().map(AssetAmortizeDetailEntity::getAssetId).collect(Collectors.toList());
            LambdaQueryWrapper<AssetAllotOutDetailEntity> outQuery = new LambdaQueryWrapper<>();
            outQuery.in(AssetAllotOutDetailEntity::getAssetId, assetIds);
            outQuery.ge(AssetAllotOutDetailEntity::getCreateTime, createTime);
            int count = assetAllotOutDetailService.count(outQuery);
            if (count > 0) {
                return CommonResponse.error("设备明细存在后续调出单，不允许弃审！");
            }

            LambdaQueryWrapper<AssetScrapDetailEntity> scrapQuery = new LambdaQueryWrapper<>();
            scrapQuery.in(AssetScrapDetailEntity::getAssetId, assetIds);
            scrapQuery.ge(AssetScrapDetailEntity::getCreateTime, createTime);
            int c = assetScrapDetailService.count(scrapQuery);
            if (c > 0) {
                return CommonResponse.error("设备明细存在后续报废单，不允许弃审！");
            }

            LambdaQueryWrapper<HandleDetailEntity> handQuery = new LambdaQueryWrapper<>();
            handQuery.in(HandleDetailEntity::getAssetId, assetIds);
            handQuery.ge(HandleDetailEntity::getCreateTime, createTime);
            int ct = handleDetailService.count(handQuery);
            if (ct > 0) {
                return CommonResponse.error("设备明细存在后续处置单，不允许弃审！");
            }
        }


        Long orgId = assetAmortizeEntity.getOrgId();
        Date amortizeDate = assetAmortizeEntity.getAmortizeDate();
        LambdaQueryWrapper<AssetAmortizeEntity> qu = new LambdaQueryWrapper<>();
        qu.eq(AssetAmortizeEntity::getOrgId, orgId);
        qu.gt(AssetAmortizeEntity::getAmortizeDate, DateUtil.format(amortizeDate, DateUtil.DATE));
        int count = assetAmortizeService.count(qu);
        if (count > 0) {
            return CommonResponse.error("该摊销单位已有后续的摊销单，不允许弃审！");
        }
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        // 弃审后回写资产卡片摊销金额
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        logger.info("弃审推送成本---");
        logger.info("删除成本中心之前的数据-处置Id---{}",assetAmortizeEntity.getId());
        CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(assetAmortizeEntity.getId());
        logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
        if(!stringCommonResponse.isSuccess()){
            throw new BusinessException(stringCommonResponse.getMsg());
        }
        //更新是否关联
        LambdaUpdateWrapper<AssetAmortizeEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.in(AssetAmortizeEntity::getId, assetAmortizeEntity.getId());
        updateWrapper.set(AssetAmortizeEntity::getRelationFlag, 0);//(1:是，0：否)
        assetAmortizeService.update(updateWrapper);

        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            for (AssetAmortizeDetailEntity entity : detailList) {
                Long assetId = entity.getAssetId();
                Long projectId = assetAmortizeEntity.getProjectId();
                BigDecimal amortizeMnyTax = entity.getAmortizeMnyTax();
                BigDecimal amortizeMny = entity.getAmortizeMny();

                AssetEntity assetEntity = assetService.selectById(assetId);
                BigDecimal sumAmortizeTaxMny = ComputeUtil.safeSub(assetEntity.getLastAmortizeTaxMny(), amortizeMnyTax);
                BigDecimal sumAmortizeMny = ComputeUtil.safeSub(assetEntity.getLastAmortizeMny(), amortizeMny);
                BigDecimal netWorthTax = ComputeUtil.safeSub(assetEntity.getOriginalValueTax(), sumAmortizeTaxMny);
                BigDecimal netWorth = ComputeUtil.safeSub(assetEntity.getOriginalValue(), sumAmortizeMny);

                LambdaUpdateWrapper<AssetEntity> wrapper = new LambdaUpdateWrapper<>();
                wrapper.eq(AssetEntity::getId, assetId);
                wrapper.eq(AssetEntity::getProjectId, projectId);
                wrapper.set(AssetEntity::getLastAmortizeDate, entity.getLastAmortizeDate());
                wrapper.set(AssetEntity::getLastAmortizeTaxMny, sumAmortizeTaxMny);
                wrapper.set(AssetEntity::getLastAmortizeMny, sumAmortizeMny);
                wrapper.set(AssetEntity::getNetWorthTax, netWorthTax);
                wrapper.set(AssetEntity::getNetWorth, netWorth);
                assetService.update(wrapper);
            }
        }
        return CommonResponse.success();
    }

}

==> ejc-proequipmentcorp-impl-3.0.0-20221020.073620-30-sources.jar: com/ejianc/business/proequipmentcorppur/asset/service/impl/AssetAmortizeBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorppur.asset.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.proequipmentcorppur.asset.bean.*;
import com.ejianc.business.proequipmentcorppur.asset.service.*;
import com.ejianc.business.proequipmentcorppur.utils.DateUtil;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ComputeUtil;
import org.apache.commons.collections.CollectionUtils;
import com.ejianc.business.procost.api.ICostDetailApi;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

@Service("assetAmortize")
public class AssetAmortizeBpmServiceImpl implements ICommonBusinessService {
    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;

    @Autowired
    private ICostDetailApi costDetailApi;

    @Autowired
    private IAssetAmortizeService assetAmortizeService;


    @Autowired
    private IAssetService assetService;

    @Autowired
    private IAssetAllotOutDetailService assetAllotOutDetailService;


    @Autowired
    private IAssetScrapDetailService assetScrapDetailService;


    @Autowired
    private IAssetHandleDetailService handleDetailService;


    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        // 审核完成回写资产卡片摊销金额
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            Date amortizeDate = assetAmortizeEntity.getAmortizeDate();
            Long projectId = assetAmortizeEntity.getProjectId();
            for (AssetAmortizeDetailEntity entity : detailList) {
                Long assetId = entity.getAssetId();
                BigDecimal amortizeMnyTax = entity.getAmortizeMnyTax();
                BigDecimal amortizeMny = entity.getAmortizeMny();


                AssetEntity assetEntity = assetService.selectById(assetId);
                BigDecimal sumAmortizeTaxMny = ComputeUtil.safeAdd(amortizeMnyTax, assetEntity.getLastAmortizeTaxMny());
                BigDecimal sumAmortizeMny = ComputeUtil.safeAdd(amortizeMny, assetEntity.getLastAmortizeMny());
                BigDecimal netWorthTax = ComputeUtil.safeSub(assetEntity.getOriginalValueTax(), sumAmortizeTaxMny);
                BigDecimal netWorth = ComputeUtil.safeSub(assetEntity.getOriginalValue(), sumAmortizeMny);

                LambdaUpdateWrapper<AssetEntity> wrapper = new LambdaUpdateWrapper<>();
                wrapper.eq(AssetEntity::getId, assetId);
                wrapper.eq(AssetEntity::getProjectId, projectId);
                wrapper.set(AssetEntity::getLastAmortizeDate, amortizeDate);
                wrapper.set(AssetEntity::getLastAmortizeTaxMny, sumAmortizeTaxMny);
                wrapper.set(AssetEntity::getLastAmortizeMny, sumAmortizeMny);
                wrapper.set(AssetEntity::getNetWorthTax, netWorthTax);
                wrapper.set(AssetEntity::getNetWorth, netWorth);
                assetService.update(wrapper);
            }
            logger.info("推送成本---");
            AssetAmortizeEntity assetAmortizeEntity1 = assetAmortizeService.selectById(billId);
            assetAmortizeService.costPush(assetAmortizeEntity1);
        }
        return CommonResponse.success();
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        // 参数是单据类型编码字符串 根据需求是否打开下面代码
        /**CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
         if(!resp.isSuccess()){
         return CommonResponse.error("无法撤回！"+resp.getMsg());
         }*/
        //TODO 弃审 校验是否被成本归集引用 引用则不能
        CommonResponse<String> checkCommonResponse = billTypeApi.checkQuote(billTypeCode, billId);
        boolean success = checkCommonResponse.isSuccess();
        if (!success){
            return CommonResponse.error("已经被归集单使用,不能弃审和撤回");
        }
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        Date createTime = assetAmortizeEntity.getCreateTime();
        if (CollectionUtils.isNotEmpty(detailList)) {
            List<Long> assetIds = detailList.stream().map(AssetAmortizeDetailEntity::getAssetId).collect(Collectors.toList());
            LambdaQueryWrapper<AssetAllotOutDetailEntity> outQuery = new LambdaQueryWrapper<>();
            outQuery.in(AssetAllotOutDetailEntity::getAssetId, assetIds);
            outQuery.ge(AssetAllotOutDetailEntity::getCreateTime, createTime);
            int count = assetAllotOutDetailService.count(outQuery);
            if (count > 0) {
                return CommonResponse.error("设备明细存在后续调出单，不允许弃审！");
            }

            LambdaQueryWrapper<AssetScrapDetailEntity> scrapQuery = new LambdaQueryWrapper<>();
            scrapQuery.in(AssetScrapDetailEntity::getAssetId, assetIds);
            scrapQuery.ge(AssetScrapDetailEntity::getCreateTime, createTime);
            int c = assetScrapDetailService.count(scrapQuery);
            if (c > 0) {
                return CommonResponse.error("设备明细存在后续报废单，不允许弃审！");
            }

            LambdaQueryWrapper<AssetHandleDetailEntity> handQuery = new LambdaQueryWrapper<>();
            handQuery.in(AssetHandleDetailEntity::getAssetId, assetIds);
            handQuery.ge(AssetHandleDetailEntity::getCreateTime, createTime);
            int ct = handleDetailService.count(handQuery);
            if (ct > 0) {
                return CommonResponse.error("设备明细存在后续处置单，不允许弃审！");
            }
        }


        Long orgId = assetAmortizeEntity.getOrgId();
        Date amortizeDate = assetAmortizeEntity.getAmortizeDate();
        LambdaQueryWrapper<AssetAmortizeEntity> qu = new LambdaQueryWrapper<>();
        qu.eq(AssetAmortizeEntity::getOrgId, orgId);
        qu.gt(AssetAmortizeEntity::getAmortizeDate, DateUtil.format(amortizeDate, DateUtil.DATE));
        int count = assetAmortizeService.count(qu);
        if (count > 0) {
            return CommonResponse.error("该摊销单位已有后续的摊销单，不允许弃审！");
        }
        return CommonResponse.success();
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        // 弃审后回写资产卡片摊销金额
        AssetAmortizeEntity assetAmortizeEntity = assetAmortizeService.selectById(billId);
        logger.info("弃审推送成本---");
        logger.info("删除成本中心之前的数据-处置Id---{}",assetAmortizeEntity.getId());
        CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(assetAmortizeEntity.getId());
        logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
        if(!stringCommonResponse.isSuccess()){
            throw new BusinessException(stringCommonResponse.getMsg());
        }
        //更新是否关联
        LambdaUpdateWrapper<AssetAmortizeEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.in(AssetAmortizeEntity::getId, assetAmortizeEntity.getId());
        updateWrapper.set(AssetAmortizeEntity::getRelationFlag, 0);//(1:是，0：否)
        assetAmortizeService.update(updateWrapper);

        List<AssetAmortizeDetailEntity> detailList = assetAmortizeEntity.getDetailList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            for (AssetAmortizeDetailEntity entity : detailList) {
                Long assetId = entity.getAssetId();
                Long projectId = assetAmortizeEntity.getProjectId();
                BigDecimal amortizeMnyTax = entity.getAmortizeMnyTax();
                BigDecimal amortizeMny = entity.getAmortizeMny();

                AssetEntity assetEntity = assetService.selectById(assetId);
                BigDecimal sumAmortizeTaxMny = ComputeUtil.safeSub(assetEntity.getLastAmortizeTaxMny(), amortizeMnyTax);
                BigDecimal sumAmortizeMny = ComputeUtil.safeSub(assetEntity.getLastAmortizeMny(), amortizeMny);
                BigDecimal netWorthTax = ComputeUtil.safeSub(assetEntity.getOriginalValueTax(), sumAmortizeTaxMny);
                BigDecimal netWorth = ComputeUtil.safeSub(assetEntity.getOriginalValue(), sumAmortizeMny);

                LambdaUpdateWrapper<AssetEntity> wrapper = new LambdaUpdateWrapper<>();
                wrapper.eq(AssetEntity::getId, assetId);
                wrapper.eq(AssetEntity::getProjectId, projectId);
                wrapper.set(AssetEntity::getLastAmortizeDate, entity.getLastAmortizeDate());
                wrapper.set(AssetEntity::getLastAmortizeTaxMny, sumAmortizeTaxMny);
                wrapper.set(AssetEntity::getLastAmortizeMny, sumAmortizeMny);
                wrapper.set(AssetEntity::getNetWorthTax, netWorthTax);
                wrapper.set(AssetEntity::getNetWorth, netWorth);
                assetService.update(wrapper);
            }
        }
        return CommonResponse.success();
    }

}
